@@ -173,7 +173,7 @@ def cmd_su(cmd, user=None):
         return run(cmd)
 
 
-def cmd_git(path=None, url=None, branch='master', tag=None, user=None):
+def cmd_git(path=None, url=None, branch='master', tag=None, user=None, ignore_perm=True):
     '''
     deploy source code by git
     :param path:
@@ -186,8 +186,6 @@ def cmd_git(path=None, url=None, branch='master', tag=None, user=None):
     :return:
     '''
 
-
-
     host_begin = url.find('@')
     host_end = url.find(':')
     request_host = url[host_begin + 1:host_end].strip()
@@ -206,6 +204,7 @@ def cmd_git(path=None, url=None, branch='master', tag=None, user=None):
         if run("test -d %s" % path).failed:
             with cd(parent):
                 cmd_su('git clone {} -b {} {}'.format(url, branch, path), user)
+                cmd_su("cd {} && git config core.fileMode false".format(path), user)
 
     with cd(path):
         with settings(warn_only=True):
@@ -234,7 +233,6 @@ def cmd_ip(card='eth0'):
     return ip
 
 
-
 def yum_install(package_name, newer=None):
     if newer:
         run('yum  --enablerepo={}  install {} -y'.format(newer, package_name))
